.. NTracer documentation master file, created by
   sphinx-quickstart on Sat Nov 23 23:00:32 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to NTracer's documentation!
===================================

Contents:

.. toctree::
   :maxdepth: 4

   example
   nonpygame_example
   ntracer


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

